@@ -15,13 +15,13 @@
 #
 from typing import (
     Any,
-    AsyncIterable,
+    AsyncIterator,
     Awaitable,
     Callable,
-    Iterable,
     Sequence,
     Tuple,
     Optional,
+    Iterator,
 )
 
 from google.cloud.accessapproval_v1.types import accessapproval
@@ -74,14 +74,14 @@ class ListApprovalRequestsPager:
         return getattr(self._response, name)
 
     @property
-    def pages(self) -> Iterable[accessapproval.ListApprovalRequestsResponse]:
+    def pages(self) -> Iterator[accessapproval.ListApprovalRequestsResponse]:
         yield self._response
         while self._response.next_page_token:
             self._request.page_token = self._response.next_page_token
             self._response = self._method(self._request, metadata=self._metadata)
             yield self._response
 
-    def __iter__(self) -> Iterable[accessapproval.ApprovalRequest]:
+    def __iter__(self) -> Iterator[accessapproval.ApprovalRequest]:
         for page in self.pages:
             yield from page.approval_requests
 
@@ -136,14 +136,14 @@ class ListApprovalRequestsAsyncPager:
         return getattr(self._response, name)
 
     @property
-    async def pages(self) -> AsyncIterable[accessapproval.ListApprovalRequestsResponse]:
+    async def pages(self) -> AsyncIterator[accessapproval.ListApprovalRequestsResponse]:
         yield self._response
         while self._response.next_page_token:
             self._request.page_token = self._response.next_page_token
             self._response = await self._method(self._request, metadata=self._metadata)
             yield self._response
 
-    def __aiter__(self) -> AsyncIterable[accessapproval.ApprovalRequest]:
+    def __aiter__(self) -> AsyncIterator[accessapproval.ApprovalRequest]:
         async def async_generator():
             async for page in self.pages:
                 for response in page.approval_requests:
